@@ -1,9 +1,10 @@
 import typer
+
 from typing import Optional
+from pathlib import Path
+from scrapse.leggitalia.leggitalia import leggitalia_app
 
-from scrapse.leggitalia import leggitalia_app
-
-__version__ = "0.2.4"
+__version__ = "0.3.5"
 
 app = typer.Typer()
 app.add_typer(leggitalia_app, name='leggitalia')
@@ -18,11 +19,13 @@ def version_callback(value: bool):
 @app.callback()
 def main(
         version: Optional[bool] = typer.Option(
-            None, "--version", callback=version_callback
+            None, '--version', '-v', callback=version_callback
         )):
     """
         Package created for the extraction of judgments.
     """
+    main_directory_path = Path('/'.join((str(Path.home()), 'scrapse')))
+    main_directory_path.mkdir(exist_ok=True, parents=True)
 
 
 if __name__ == "__main__":
